/**
   Randomly delete fragments from each model.

   This class is a "pipeline stage" because it
   implements the PipelineStage interface, which
   consistes of a single method, processModel().
*/
import java.util.LinkedList;
import java.util.Random;

public class DropFragmentShader implements PipelineStage
{
   private double probability;
   private Random generator;

   public DropFragmentShader(double probability)
   {
      this.probability = probability;

      generator = new Random();
   }


   /**
      Randomly drop fragments from this model..
   */
   public Model processModel(Model model)
   {
      for (Triangle t : model.triangleList)
      {
         LinkedList<Fragment> newFragList = new LinkedList<Fragment>();

         for (Fragment f : t.fragments)
         {
            double r = generator.nextDouble();
            if (r >= probability)
               newFragList.add(f);
         }

         t.fragments = newFragList;
      }

      return model;
   }
}